# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['gns3fy']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=0.31.0,<0.32.0', 'requests>=2.22,<3.0']

setup_kwargs = {
    'name': 'gns3fy',
    'version': '0.1.1',
    'description': 'Python wrapper around GNS3 Server API',
    'long_description': '# gns3fy\nPython wrapper around [GNS3 Server API](http://api.gns3.net/en/2.2/index.html).\n\nIts main objective is to interact with the GNS3 server in a programatic way, so it can be integrated with the likes of Ansible, docker and scripts.\n\n## Install\n\n```\npip install gns3fy\n```\n\n### Development version\n\nUse [poetry](https://github.com/sdispater/poetry) to install the package when cloning it.\n\n## How it works\n\nYou can start the library and use the `Gns3Connector` object and the `Project` object.\n\nFor example:\n\n```python\nimport gns3fy\n\n# Define the server object to establish the connection\ngns3_server = gns3fy.Gns3Connector("http://<server address>:3080")\n\n# Define the lab you want to load and assign the server connector\nlab = gns3fy.Project(name="API_TEST", connector=gns3_server)\n\n# Retrieve its information and display\nlab.get()\n\nprint(lab)\n# Project(project_id=\'4b21dfb3-675a-4efa-8613-2f7fb32e76fe\', name=\'API_TEST\', status=\'opened\', ...\n\n# Access the project attributes\nprint(f"Name: {lab.name} -- Status: {lab.status} -- Is auto_closed?: {lab.auto_close}")\n# Name: API_TEST -- Status: closed -- Is auto_closed?: False\n\n# Open the project\nlab.open()\nprint(lab.status)\n# opened\n\n# Verify the stats\nprint(lab.stats)\n#\xa0{\'drawings\': 0, \'links\': 4, \'nodes\': 6, \'snapshots\': 0}\n\n# List the names and status of all the nodes in the project\nfor node in lab.nodes:\n    print(f"Node: {node.name} -- Node Type: {node.node_type} -- Status: {node.status}")\n# Node: Ethernetswitch-1 -- Node Type: ethernet_switch -- Status: started\n#\xa0...\n```\n\nTake a look at the API documentation for complete information about the attributes retrieved.\n\n### Usage of Node and Link objects\n\nYou have access to the `Node` and `Link` objects as well, this gives you the ability to start, stop, suspend the individual element in a GNS3 project.\n\n```python\nfrom gns3fy import Node, Link, Gns3Connector\n\nPROJECT_ID = "<some project id>"\nserver = Gns3Connector("http://<server address>:3080")\n\nalpine1 = Node(project_id=PROJECT_ID, name="alpine-1", connector=server)\n\nalpine1.get()\nprint(alpine1)\n# Node(name=\'alpine-1\', node_type=\'docker\', node_directory= ...\n\n# And you can access the attributes the same way as the project\nprint(f"Name: {alpine1.name} -- Status: {alpine1.status} -- Console: {alpine1.console}")\n# Name: alpine-1 -- Status: started -- Console: 5005\n\n# Stop the node and start (you can just restart it as well)\nalpine1.stop()\nprint(alpine1.status)\n# stopped\n\nalpine1.start()\nprint(alpine1.status)\n# started\n\n# You can also see the Link objects assigned to this node\nprint(alpine1.links)\n# [Link(link_id=\'4d9f1235-7fd1-466b-ad26-0b4b08beb778\', link_type=\'ethernet\', ....\n\n# And in the same way you can interact with a Link object\nlink1 = alpine1.links[0]\nprint(f"Link Type: {link1.link_type} -- Capturing?: {link1.capturing} -- Endpoints: {link1.nodes}")\n# Link Type: ethernet -- Capturing?: False -- Endpoints: [{\'adapter_number\': 2, ...\n```\n\n### Bonus\n\nYou also have some commodity methods like the `nodes_summary` and `links_summary`, that if used with a library like `tabulate` you can see the following:\n\n```python\n...\nfrom tabulate import tabulate\n\nnodes_summary = lab.nodes_summary(is_print=False)\n\nprint(\n    tabulate(nodes_summary, headers=["Node", "Status", "Console Port", "ID"])\n)\n# Node              Status      Console Port  ID\n# ----------------  --------  --------------  ------------------------------------\n# Ethernetswitch-1  started             5000  da28e1c0-9465-4f7c-b42c-49b2f4e1c64d\n# IOU1              started             5001  de23a89a-aa1f-446a-a950-31d4bf98653c\n# IOU2              started             5002  0d10d697-ef8d-40af-a4f3-fafe71f5458b\n# vEOS-4.21.5F-1    started             5003  8283b923-df0e-4bc1-8199-be6fea40f500\n# alpine-1          started             5005  ef503c45-e998-499d-88fc-2765614b313e\n# Cloud-1           started                   cde85a31-c97f-4551-9596-a3ed12c08498\n\nlinks_summary = lab.links_summary(is_print=False)\nprint(\n    tabulate(links_summary, headers=["Node A", "Port A", "Node B", "Port B"])\n)\n# Node A          Port A       Node B            Port B\n# --------------  -----------  ----------------  -----------\n# IOU1            Ethernet1/0  IOU2              Ethernet1/0\n# vEOS-4.21.5F-1  Management1  Ethernetswitch-1  Ethernet0\n# vEOS-4.21.5F-1  Ethernet1    alpine-1          eth0\n# Cloud-1         eth1         Ethernetswitch-1  Ethernet7\n```\n',
    'author': 'David Flores',
    'author_email': 'davidflores7_8@hotmail.com',
    'url': 'https://github.com/davidban77/gns3fy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
